The server's TLS/SSL certificate is self-signed. Self-signed
certificates are not trusted by browsers and other HTTP clients,
especially because TLS/SSL man-in-the-middle attacks typically use
self-signed certificates to eavesdrop on TLS/SSL connections.